#!/bin/sh

if [ "$1" = "" ]; then
  echo -e 'Usage: mptogif1.sh FILE [DPI [-noantialias]]\n'
  exit 1
fi

if [ "$2" = "" ]; then
  DPI=300
else
  DPI=$2
fi

DIR=$PWD
FILE=$DIR/`echo $1 | awk 'BEGIN{FS=".";} {print $1}'`
EPS=$FILE.eps
GIF=$FILE.gif

cd /tmp
cp $DIR/$1 mptogif.$$.mp
echo "\\hsize=15.85cm\\vsize=13.48cm\\input epsf\\nopagenumbers\\leavevmode\\noindent\\epsfbox{mptogif.$$.1}\\vfill\\end" > mptogif.$$.tex
for file in $DIR/mbmac.mp $DIR/mbmacpf.mp $DIR/mbmac.tex $DIR/fop.tex $DIR/*.tfm $DIR/*.*pk; do
  ln -sf $file
done

mpost mptogif.$$.mp
cp mptogif.$$.1 $FILE.1
tex mptogif.$$.tex
dvips -T 15cm,16cm -o mptogif.$$.ps mptogif.$$.dvi
psfixbb -o $EPS mptogif.$$.ps
gs -q -dSAFER -sPAPERSIZE=a5 -sDEVICE=ppmraw -sOutputFile=- -dNOPAUSE -r"$DPI"x"$DPI" $EPS quit.ps | pnmcrop > mptogif.$$.pnm
if [ "$3" != "-noantialias" ]; then
  pnmscale 0.5 < mptogif.$$.pnm | ppmtogif > $GIF
else
  ppmtogif < mptogif.$$.pnm > $GIF
fi

rm mptogif.$$.*
rm mbmac.mp mbmacpf.mp mbmac.tex fop.tex
cd $DIR

